@@ -1,4 +1,4 @@
 .onLoad <- function(libname, pkgname) {
 	#utils::globalVariables("HPOSimEnv")
-	initialize()
+	.initial()
 }
